pub fn compute_diff(
existing: &InferredSchema,
new: &InferredSchema,
) -> SchemaDiffExpand description
Compute the diff between an existing schema and a new payload’s inferred schema
pub fn compute_diff(
existing: &InferredSchema,
new: &InferredSchema,
) -> SchemaDiffCompute the diff between an existing schema and a new payload’s inferred schema